@@ -1,5 +1,4 @@
-use nix::errno;
-use std::path::Path;
+use std::path::{Path, PathBuf};
 
 use crate::*;
 
@@ -16,6 +15,20 @@ impl Link {
         Link { ptr }
     }
 
+    /// Create link from BPF FS file.
+    pub fn open<P: AsRef<Path>>(&mut self, path: P) -> Result<Self> {
+        let path_c = util::path_to_cstring(path)?;
+        let path_ptr = path_c.as_ptr();
+        let ptr = unsafe { libbpf_sys::bpf_link__open(path_ptr) };
+
+        let err = unsafe { libbpf_sys::libbpf_get_error(ptr as *const _) };
+        if err != 0 {
+            return Err(Error::System(err as i32));
+        }
+
+        Ok(Link::new(ptr))
+    }
+
     /// Takes ownership from pointer.
     ///
     /// # Safety
@@ -28,11 +41,7 @@ impl Link {
     /// Replace the underlying prog with `prog`.
     pub fn update_prog(&mut self, prog: Program) -> Result<()> {
         let ret = unsafe { libbpf_sys::bpf_link__update_program(self.ptr, prog.ptr) };
-        if ret != 0 {
-            Err(Error::System(errno::errno()))
-        } else {
-            Ok(())
-        }
+        util::parse_ret(ret)
     }
 
     /// Release "ownership" of underlying BPF resource (typically, a BPF program
@@ -55,30 +64,46 @@ impl Link {
         let path_ptr = path_c.as_ptr();
 
         let ret = unsafe { libbpf_sys::bpf_link__pin(self.ptr, path_ptr) };
-        if ret != 0 {
-            // Error code is returned negative, flip to positive to match errno
-            Err(Error::System(-ret))
-        } else {
-            Ok(())
-        }
+        util::parse_ret(ret)
     }
 
     /// [Unpin](https://facebookmicrosites.github.io/bpf/blog/2018/08/31/object-lifetime.html#bpffs)
     /// from bpffs
     pub fn unpin(&mut self) -> Result<()> {
         let ret = unsafe { libbpf_sys::bpf_link__unpin(self.ptr) };
-        if ret != 0 {
-            // Error code is returned negative, flip to positive to match errno
-            Err(Error::System(-ret))
-        } else {
-            Ok(())
-        }
+        util::parse_ret(ret)
     }
 
     /// Returns the file descriptor of the link.
+    #[deprecated(since = "0.17.0", note = "please use `fd` instead")]
     pub fn get_fd(&self) -> i32 {
         unsafe { libbpf_sys::bpf_link__fd(self.ptr) }
     }
+
+    /// Returns the file descriptor of the link.
+    pub fn fd(&self) -> i32 {
+        unsafe { libbpf_sys::bpf_link__fd(self.ptr) }
+    }
+
+    /// Returns path to BPF FS file or `None` if not pinned.
+    pub fn pin_path(&self) -> Option<PathBuf> {
+        let path_ptr = unsafe { libbpf_sys::bpf_link__pin_path(self.ptr) };
+        if path_ptr.is_null() {
+            return None;
+        }
+
+        let path = match util::c_ptr_to_string(path_ptr) {
+            Ok(p) => p,
+            Err(_) => return None,
+        };
+
+        Some(PathBuf::from(path.as_str()))
+    }
+
+    pub fn detach(&self) -> Result<()> {
+        let ret = unsafe { libbpf_sys::bpf_link__detach(self.ptr) };
+        util::parse_ret(ret)
+    }
 }
 
 impl Drop for Link {
