@@ -98,8 +98,8 @@ fn test_object_maps_iter() {
     for map in obj.maps_iter() {
         eprintln!("{}", map.name());
     }
-    // This will include .rodata, so our expected count is 3, not 2
-    assert!(obj.maps_iter().count() == 3);
+    // This will include .rodata and .bss, so our expected count is 4, not 2
+    assert!(obj.maps_iter().count() == 4);
 }
 
 #[test]
@@ -319,7 +319,7 @@ fn test_object_map_pin() {
     let mut obj = get_test_object("runqslower.bpf.o");
     let map = obj.map_mut("start").expect("failed to find map");
 
-    let path = "/sys/fs/bpf/mymap";
+    let path = "/sys/fs/bpf/mymap_test_object_map_pin";
 
     // Unpinning a unpinned map should be an error
     assert!(map.unpin(path).is_err());
@@ -417,7 +417,7 @@ fn test_object_link_pin() {
 fn test_object_reuse_pined_map() {
     bump_rlimit_mlock();
 
-    let path = "/sys/fs/bpf/mymap";
+    let path = "/sys/fs/bpf/mymap_test_object_reuse_pined_map";
     let key = vec![1, 2, 3, 4];
     let val = vec![1, 2, 3, 4, 5, 6, 7, 8];
 
